R/TabulateGelmanResults.R
TabulateGelmanResults.RdReturns a data table of mu and scale reduction factor estimates from a Gelman-Rubin diagnostic run using Discuit in Julia or R.
TabulateGelmanResults(gelmanResults)
| gelmanResults | data (the results of a Gelman diagnostic). |
|---|
# NOT RUN { TabulateGelmanResults(gelmanResults) # }